@@ -16,25 +16,30 @@ from .s3_file_storage.s3_file_storage import S3FileStorage
 
 
 def _get_disc_file_storage(
-        location: str, max_workers: str | None = None,
+        location: str, max_capacity_gb: float,
+        max_workers: str | None = None,
         root_dir: str | None = None,
         metrics: MetricsRegistry | None = None,
         storage: Type[DiscFileStorage] | None = None,
 ) -> DiscFileStorage:
     storage = storage or DiscFileStorage
     config = storage.Config(
-        location=location, root_dir=root_dir or "", max_workers=max_workers if max_workers is None else int(max_workers)
+        location=location,
+        root_dir=root_dir or "",
+        max_workers=max_workers if max_workers is None else int(max_workers),
+        max_capacity_gb=max_capacity_gb,
     )
     context = storage.Context(metrics=metrics or MetricsRegistry(MetricsRegistry.Config()))
     return storage(config, context)
 
 
-def _get_s3_file_storage(access_key: str, secret_key: str, address: str | None = None, region_name: str | None = None,
+def _get_s3_file_storage(access_key: str, secret_key: str, max_capacity_gb: float,
+                         address: str | None = None, region_name: str | None = None,
                          bucket_name: str | None = None, root_dir: str | None = None,
                          metrics: MetricsRegistry | None = None,
                          storage: Type[S3FileStorage] | None = None,
                          ) -> S3FileStorage:
-    kwargs = {"access_key": access_key, "secret_key": secret_key}
+    kwargs = {"access_key": access_key, "secret_key": secret_key, "max_capacity_gb": max_capacity_gb}
     kwargs |= {"address": address} if address is not None else {}
     kwargs |= {"region_name": region_name} if region_name is not None else {}
     kwargs |= {"bucket_name": bucket_name} if bucket_name is not None else {}
@@ -59,7 +64,7 @@ S3_URL_EXAMPLE = 's3://access:secret@localhost:7480/Default?bucket=abm-bucket&ro
 
 
 def get_file_storage(
-        url: str, metrics: MetricsRegistry | None = None,
+        url: str, max_capacity_gb: float = float('inf'), metrics: MetricsRegistry | None = None,
         s3_storage: Type[S3FileStorage] | None = None, disc_storage: Type[DiscFileStorage] | None = None
 ) -> AbstractFileStorage:
     parsed_url = urlparse(url)
@@ -68,8 +73,8 @@ def get_file_storage(
         assert not parsed_url.netloc, (f"File url should not have user, password, host or port, "
                                        f"got: {parsed_url.netloc}, format: {S3_URL_FORMAT}, example: {S3_URL_EXAMPLE}")
         result = _get_disc_file_storage(
-            location=parsed_url.path, root_dir=_pop_get_first(query_params, 'root_dir'),
-            max_workers=_pop_get_first(query_params, 'max_workers'), metrics=metrics, storage=disc_storage
+            location=parsed_url.path, max_capacity_gb=max_capacity_gb, root_dir=_pop_get_first(query_params, 'root_dir'),
+            max_workers=_pop_get_first(query_params, 'max_workers'), metrics=metrics, storage=disc_storage,
         )
     elif parsed_url.scheme == "s3" or parsed_url.scheme == "s3s":
         assert parsed_url.username, f'Missing access_key, format: {S3_URL_FORMAT}, example: {S3_URL_EXAMPLE}'
@@ -82,7 +87,7 @@ def get_file_storage(
         result = _get_s3_file_storage(
             access_key=parsed_url.username, secret_key=parsed_url.password, address=address, region_name=path or None,
             bucket_name=_pop_get_first(query_params, 'bucket'), root_dir=_pop_get_first(query_params, 'root_dir'),
-            metrics=metrics, storage=s3_storage
+            metrics=metrics, storage=s3_storage, max_capacity_gb=max_capacity_gb,
         )
     else:
         raise TypeError(f"Attempt to get storage from unsupported scheme '{parsed_url.scheme}', supported: file|s3|s3s")
